==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/inputs/ListServerSitesControllerHealthSummaryPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.inputs

import com.pulumi.azurenative.offazure.inputs.ListServerSitesControllerHealthSummaryPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property siteName Site name
 */
public data class ListServerSitesControllerHealthSummaryPlainArgs(
    public val resourceGroupName: String,
    public val siteName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.offazure.inputs.ListServerSitesControllerHealthSummaryPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.offazure.inputs.ListServerSitesControllerHealthSummaryPlainArgs =
        com.pulumi.azurenative.offazure.inputs.ListServerSitesControllerHealthSummaryPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListServerSitesControllerHealthSummaryPlainArgs].
 */
@PulumiTagMarker
public class ListServerSitesControllerHealthSummaryPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var siteName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ygjrbcfvsojdacfo")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("rjxbtppajvtdrpmm")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    internal fun build(): ListServerSitesControllerHealthSummaryPlainArgs =
        ListServerSitesControllerHealthSummaryPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/inputs/ListServerSitesControllerHealthSummaryPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.inputs

import com.pulumi.azurenative.offazure.inputs.ListServerSitesControllerHealthSummaryPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property siteName Site name
 */
public data class ListServerSitesControllerHealthSummaryPlainArgs(
    public val resourceGroupName: String,
    public val siteName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.offazure.inputs.ListServerSitesControllerHealthSummaryPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.offazure.inputs.ListServerSitesControllerHealthSummaryPlainArgs =
        com.pulumi.azurenative.offazure.inputs.ListServerSitesControllerHealthSummaryPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListServerSitesControllerHealthSummaryPlainArgs].
 */
@PulumiTagMarker
public class ListServerSitesControllerHealthSummaryPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var siteName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("mdqhktyfreibmiwd")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("hypwmciwasdmdbft")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    internal fun build(): ListServerSitesControllerHealthSummaryPlainArgs =
        ListServerSitesControllerHealthSummaryPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        )
}
